/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/*****************************************************************************/
/** \file gpio.h
**
** History:
** 
*****************************************************************************/
#ifndef __GPIO_H__
#define __GPIO_H__

#ifdef __cplusplus
extern "C"
{
#endif

/*****************************************************************************/
/* Include files */
/*****************************************************************************/
#include "cms32f0332.h"
/*****************************************************************************/
/* Global pre-processor symbols/macros ('#define') */
/*****************************************************************************/
/*----------------------------------------------------------------------------
 **GPIO PORT & PIN
-----------------------------------------------------------------------------*/
#define		GPIO_PIN_NUM_MAX	(0x08UL)
#define 	GPIO_PIN_0_MSK		(0x01UL)		/*GPIO Pin 0 mask*/
#define 	GPIO_PIN_1_MSK		(0x02UL)		/*GPIO Pin 1 mask*/
#define 	GPIO_PIN_2_MSK		(0x04UL)		/*GPIO Pin 2 mask*/
#define 	GPIO_PIN_3_MSK		(0x08UL)		/*GPIO Pin 3 mask*/		
#define 	GPIO_PIN_4_MSK		(0x10UL)		/*GPIO Pin 4 mask*/
#define 	GPIO_PIN_5_MSK		(0x20UL)		/*GPIO Pin 5 mask*/
#define 	GPIO_PIN_6_MSK		(0x40UL)		/*GPIO Pin 6 mask*/
#define 	GPIO_PIN_7_MSK		(0x80UL)		/*GPIO Pin 7 mask*/

#define 	GPIO_PIN_0			(0x00UL)		/*GPIO Pin 0 Num*/
#define 	GPIO_PIN_1			(0x01UL)		/*GPIO Pin 1 Num*/
#define 	GPIO_PIN_2			(0x02UL)		/*GPIO Pin 2 Num*/
#define 	GPIO_PIN_3			(0x03UL)		/*GPIO Pin 3 Num*/
#define 	GPIO_PIN_4			(0x04UL)		/*GPIO Pin 4 Num*/		
#define 	GPIO_PIN_5			(0x05UL)		/*GPIO Pin 5 Num*/
#define 	GPIO_PIN_6			(0x06UL)		/*GPIO Pin 6 Num*/
#define 	GPIO_PIN_7			(0x07UL)		/*GPIO Pin 7 Num*/

/*----------------------------------------------------------------------------
 **GPIO ģʽ 
-----------------------------------------------------------------------------*/
#define 	GPIO_MODE_INPUT						(0x00UL)		/*ͨģʽ*/
#define 	GPIO_MODE_OUTPUT					(0x01UL)		/*ģʽ*/
#define 	GPIO_MODE_INPUT_WITH_PULL_UP		(0x03UL)		/*ģʽ*/
#define		GPIO_MODE_INPUT_WITH_PULL_DOWN		(0x04UL)		/*ģʽ*/
#define 	GPIO_MODE_OPEN_DRAIN_WITHOUT_PULL_UP	(0x02UL)		/*Ŀ©ģʽ*/
#define		GPIO_MODE_OPEN_DRAIN_WITH_PULL_UP		(0x05UL)		/*Ŀ©ģʽ*/
/*----------------------------------------------------------------------------
 **GPIO жģʽ
-----------------------------------------------------------------------------*/
//-----------״̬-----------------------------------------------------
#define 	GPIO_INT_LEVEL_LOW			(0x00UL)			/*GPIOƽʽеĵ͵ƽʽ*/
#define 	GPIO_INT_LEVEL_HIGH			(0x01UL)			/*GPIOƽʽеĸߵƽʽ*/
#define 	GPIO_INT_EDGE_FALLING		(0x02UL)			/*GPIOشʽе½شʽ*/
#define 	GPIO_INT_EDGE_RISING		(0x03UL)			/*GPIOشʽеشʽ*/
#define 	GPIO_INT_EDGE_BOTH			(0x04UL)			/*GPIOشʽе½شʽ*/
//-----------״̬--------------------------------------------------------
#define 	GPIO_WEKEUP_INT_EDGE_FALLING (0x5UL)			/*½ػѼж*/
#define 	GPIO_WEKEUP_INT_EDGE_RISING  (0x6UL)			/*ػѼж*/
#define 	GPIO_WEKEUP_INT_EDGE_BOTH	 (0x7UL)			/*½ػѼж*/
/*----------------------------------------------------------------------------
 **GPIO ˲
-----------------------------------------------------------------------------*/
#define 	GPIO_FILCLK_1			(0x0UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(0~1)*/
#define 	GPIO_FILCLK_2			(0x1UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(1~2)*/
#define 	GPIO_FILCLK_3			(0x2UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(2~3)*/
#define 	GPIO_FILCLK_5			(0x3UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(4~5)*/
#define 	GPIO_FILCLK_9			(0x4UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(8~9)*/
#define 	GPIO_FILCLK_17			(0x5UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(16~17)*/
#define 	GPIO_FILCLK_33			(0x6UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(32~33)*/
#define 	GPIO_FILCLK_65			(0x7UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(64~65)*/
#define 	GPIO_FILCLK_129			(0x8UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(128~129)*/
#define 	GPIO_FILCLK_257			(0x9UL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(256~257)*/
#define 	GPIO_FILCLK_513			(0xAUL<<GPIO_DIDB_DBCK_Pos)		/*Filter Clk = HCLK*(512~513)*/

/*****************************************************************************
 ** \brief	GPIO_CONFIG_IO_MODE
 **			IOģʽ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinNum: GPIO_PIN_0 ~ GPIO_PIN_7
 **				IOMode (1)GPIO_MODE_INPUT
 **						 (2)GPIO_MODE_OUTPUT
 **						 (3)GPIO_MODE_OPEN_DRAIN_WITHOUT_PULL_UP
 **						 (4)GPIO_MODE_INPUT_WITH_PULL_UP
 **						 (5)GPIO_MODE_INPUT_WITH_PULL_DOWN
 **						 (6)GPIO_MODE_OPEN_DRAIN_WITH_PULL_UP 
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_CONFIG_IO_MODE(port,PinNum ,IOMode)  do{\
														port->PMS &= ~(GPIO_PMS_PMS0_Msk <<(PinNum*4));\
														port->PMS |= (IOMode <<(PinNum*4));\
													 }while(0)
/*****************************************************************************
 ** \brief	GPIO_ENABLE_DO_SHIELD
 **			GPIOд
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_ENABLE_DO_SHIELD(port,PinMask)  do{\
													port->DOM = PinMask;\
												}while(0)													 
/*****************************************************************************
 ** \brief	GPIO_DISABLE_DO_SHIELD
 **			رGPIOд
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_DISABLE_DO_SHIELD(port,PinMask)  do{\
													port->DOM = ~(PinMask);\
												}while(0)														 

/*****************************************************************************
 ** \brief	 GPIO_DISABLE_LOW_CURRENT
 **			 رGPIOСģʽ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_DISABLE_LOW_CURRENT(port,PinMask)  do{\
													port->DR &= ~(PinMask);\
												}while(0)	
/*****************************************************************************
 ** \brief	 GPIO_ENABLE_LOW_CURRENT
 **			 GPIOСģʽ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_ENABLE_LOW_CURRENT(port,PinMask)  do{\
													port->DR |= (PinMask);\
												}while(0)

/*****************************************************************************
 ** \brief	 GPIO_DISABLE_SLOW_SLOPE
 **			 رGPIOб
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_DISABLE_SLOW_SLOPE(port,PinMask)  do{\
													port->SR &= ~(PinMask);\
												}while(0)	
/*****************************************************************************
 ** \brief	 GPIO_ENABLE_SLOW_SLOPE
 **			 GPIOб
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_ENABLE_SLOW_SLOPE(port,PinMask)  do{\
													port->SR |= (PinMask);\
												}while(0)	

/*****************************************************************************
 ** \brief	 GPIO_SET_PIN
 **			 ܽλ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_SET_PIN(port,PinMask)  do{\
											port->DOSET = (PinMask);\
										}while(0)	
/*****************************************************************************
 ** \brief	 GPIO_RESET_PIN
 **			 /λܽ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	 
*****************************************************************************/
#define   GPIO_RESET_PIN(port,PinMask)  do{\
											port->DOCLR = (PinMask);\
										   }while(0)	

/*****************************************************************************
 ** \brief	 GPIO_GET_RIS_FLAG
 **			 ȡIOжԴ־
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinNum: GPIO_PIN_0 ~ GPIO_PIN_7
 ** \return 0:жϣ 1δж
 ** \note	 
*****************************************************************************/
#define   GPIO_GET_RIS_FLAG(port,PinNum)  (((port->RIS & (0x1UL<<PinNum))? 1:0))

/*****************************************************************************
 ** \brief	 GPIOToggle
 **			 תIO
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinNum: GPIO_PIN_0 ~ GPIO_PIN_7
 ** \return None
 ** \note	 
*****************************************************************************/
#define GPIOToggle(GPIOx,bitV) (((GPIOx->DO)& (1<<bitV))? ((GPIOx->DO) &= ~(1<<bitV)):((GPIOx->DO) |= (1<<bitV)))		
											 
/*****************************************************************************/
/* Global type definitions ('typedef') */
/*****************************************************************************/


/*****************************************************************************/
/* Global variable declarations ('extern', definition in C source) */
/*****************************************************************************/


/*****************************************************************************/
/* Global function prototypes ('extern', definition in C source) */
/*****************************************************************************/

/*****************************************************************************
 ** \brief	 GPIO_ConfigRunMode
 **			 IOģʽ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 **				Mode:	 (1)GPIO_MODE_INPUT
 **						 (2)GPIO_MODE_OUTPUT
 **						 (3)GPIO_MODE_OPEN_DRAIN_WITHOUT_PULL_UP
 **						 (4)GPIO_MODE_OPEN_DRAIN_WITH_PULL_UP
 **						 (5)GPIO_MODE_INPUT_WITH_PULL_UP
 **						 (6)GPIO_MODE_INPUT_WITH_PULL_DOWN
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_ConfigRunMode(GPIO_T *port, uint32_t PinMask, uint32_t Mode);
/*****************************************************************************
 ** \brief	 GPIO_EnableFilter
 **			 IO˲
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 **				Fclk:	 (1)GPIO_FILCLK_1
 **						 (2)GPIO_FILCLK_2
 **						 (3)GPIO_FILCLK_3
 **						 (4)GPIO_FILCLK_5
 **						 (5)GPIO_FILCLK_9
 **						 (6)GPIO_FILCLK_17
 **						 (7)GPIO_FILCLK_33
 **						 (8)GPIO_FILCLK_65
 **						 (9)GPIO_FILCLK_129 
 **						 (10)GPIO_FILCLK_257 
 **						 (11)GPIO_FILCLK_513 
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_EnableFilter(GPIO_T *port, uint32_t PinMask, uint32_t Fclk);
/*****************************************************************************
 ** \brief	 GPIO_DisableFilter
 **			 رIO˲
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_DisableFilter(GPIO_T *port, uint32_t PinMask);

/*****************************************************************************
 ** \brief	 GPIO_EnableInt
 **			 IOж
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 **				Mode: (1)GPIO_INT_LEVEL_LOW
 **					  (2)GPIO_INT_LEVEL_HIGH
 **					  (3)GPIO_INT_EDGE_FALLING 
 **					  (4)GPIO_INT_EDGE_RISING
 **					  (5)GPIO_INT_EDGE_BOTH
 **					  (6)GPIO_WEKEUP_INT_EDGE_FALLING
 **					  (7)GPIO_WEKEUP_INT_EDGE_RISING
 **					  (8)GPIO_WEKEUP_INT_EDGE_BOTH
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_EnableInt(GPIO_T *port, uint32_t PinMask, uint32_t IntMode);

/*****************************************************************************
 ** \brief	 GPIO_DisableInt
 **			 رIOж
 ** \param [in]port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **		       PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_DisableInt(GPIO_T *port, uint32_t Pin);

/*****************************************************************************
 ** \brief	 GPIO_GetIntFlag
 **			 ȡIOʹжϱ־λ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinNum: GPIO_PIN_0 ~ GPIO_PIN_7
 ** \return  0δж 1жʹܲж
 ** \note	
*****************************************************************************/
uint32_t GPIO_GetIntFlag(GPIO_T *port, uint32_t PinNum);

/*****************************************************************************
 ** \brief	 GPIO_ClearIntFlag
 **			 IOжϱ־λ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinNum: GPIO_PIN_0 ~ GPIO_PIN_7
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_ClearIntFlag(GPIO_T *port, uint32_t PinNum);



#ifdef __cplusplus
}
#endif
#endif /* __GPIO_H__ */

