/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/*****************************************************************************/
/** \file pga.h
**
** History:
** 
*****************************************************************************/
#ifndef __PGA_H_
#define __PGA_H_

#ifdef __cplusplus
extern "C"
{
#endif

/*****************************************************************************/
/* Include files */
/*****************************************************************************/
#include "cms32f0332.h"
/*****************************************************************************/
/* Global pre-processor symbols/macros ('#define') */
/*****************************************************************************/
/*----------------------------------------------------------------------------
 **PGAģʽ
-----------------------------------------------------------------------------*/
#define PGA_MS_PGA		(0x0UL)
#define PGA_MS_OP		(0x1UL)

/*----------------------------------------------------------------------------
 **PGA	ѡ
-----------------------------------------------------------------------------*/
#define		PGA_GAIN_4			(0x00UL)					/*Ϊ4x*/
#define		PGA_GAIN_8			(0x01UL<<PGA_CON_GS_Pos)	/*Ϊ8x*/
#define		PGA_GAIN_10			(0x02UL<<PGA_CON_GS_Pos)	/*Ϊ10x*/
#define		PGA_GAIN_12			(0x03UL<<PGA_CON_GS_Pos)	/*Ϊ12x*/			
#define		PGA_GAIN_14			(0x04UL<<PGA_CON_GS_Pos)	/*Ϊ14x*/
#define		PGA_GAIN_16			(0x05UL<<PGA_CON_GS_Pos)	/*Ϊ16x*/	
#define		PGA_GAIN_32			(0x06UL<<PGA_CON_GS_Pos)	/*Ϊ32x*/
/*----------------------------------------------------------------------------
 **PGA	ӵضѡ
-----------------------------------------------------------------------------*/
#define		PGA_R_GND			(0x00UL)					/*ӵڲGND*/
#define		PGA_R_PIN			(0x01UL<<PGA_CON_RGS_Pos)	/*ӵAGND*/
			
/*----------------------------------------------------------------------------
 **PGA	
-----------------------------------------------------------------------------*/
#define		PGA_POSSEL_P0		(0x00UL)					/*ӵPGA P0*/
#define		PGA_POSSEL_P1		(0x01UL<<PGA_CON_PS_Pos)	/*ӵPGA P1*/
#define		PGA_POSSEL_P2		(0x02UL<<PGA_CON_PS_Pos)	/*ӵPGA P2*/
#define		PGA_POSSEL_P3		(0x03UL<<PGA_CON_PS_Pos)	/*ӵPGA P3*/							
/*****************************************************************************/
/* Global type definitions ('typedef') */
/*****************************************************************************/


/*****************************************************************************/
/* Global variable declarations ('extern', definition in C source) */
/*****************************************************************************/


/*****************************************************************************/
/* Global function prototypes ('extern', definition in C source) */
/*****************************************************************************/
/*****************************************************************************
 ** \brief	 PGA_ConfigMode
 **			 PGAģʽ
 ** \param [in] pga :PGA0 PGA1
 **				mode : (1)PGA_MS_PGA
 **					   (2)PGA_MS_OP
 ** \return  none	
 ** \note   
 *****************************************************************************/
void PGA_ConfigMode(PGA_T *pga, uint32_t mode);

/*****************************************************************************
 ** \brief	 PGA_ConfigPositive
 **			 PGA
 ** \param [in] pga :PGA0 PGA1
 **				Positive:	(1)PGA_POSSEL_P0
 **							(2)PGA_POSSEL_P1
 **							(3)PGA_POSSEL_P2
 **							(4)PGA_POSSEL_P3
 ** \return  none	
 ** \note    
 *****************************************************************************/
void PGA_ConfigPositive(PGA_T *pga, uint32_t Positive);

/*****************************************************************************
 ** \brief	 OPA_ConfigGain
 **			 PGA
 ** \param [in] pga :PGA0 PGA1
 **				Gain:  (1)PGA_GAIN_4		
 **					   (2)PGA_GAIN_8 
 **					   (3)PGA_GAIN_10 
 **					   (4)PGA_GAIN_12 
 **					   (5)PGA_GAIN_14 
 **					   (6)PGA_GAIN_16 
 **					   (6)PGA_GAIN_32 
 ** \return  none
 ** \note    
 *****************************************************************************/
void PGA_ConfigGain(PGA_T *pga, uint32_t Gain);

/*****************************************************************************
 ** \brief	 PGA_ConfigResistorGnd
 **			 PGAӵض
 ** \param [in] pga :PGA0 PGA1
 **				GndMode:	(1)PGA_R_GND
 **							(2)PGA_R_PIN
 ** \return  none	
 ** \note    
 *****************************************************************************/
void PGA_ConfigResistorGnd(PGA_T *pga, uint32_t GndMode);

/*****************************************************************************
 ** \brief	 PGA_EnableOutput
 **			 PGA
 ** \param [in] pga :PGA0 PGA1
 ** \return  none	
 ** \note    
 *****************************************************************************/
void PGA_EnableOutput(PGA_T *pga);
/*****************************************************************************
 ** \brief	 PGA_DisableOutput
 **			 رPGA
 ** \param [in] pga :PGA0 PGA1
 ** \return  none	
 ** \note    
 *****************************************************************************/
void PGA_DisableOutput(PGA_T *pga);

/*****************************************************************************
 ** \brief	 PGA_Start
 **			 PGA
 ** \param [in] pga :PGA0 PGA1
 ** \return  none	
 ** \note    
 *****************************************************************************/
void PGA_Start(PGA_T *pga);

/*****************************************************************************
 ** \brief	 PGA_Stop
 **			 رPGA
 ** \param [in] pga :PGA0 PGA1
 ** \return  none	
 ** \note    
 *****************************************************************************/
void PGA_Stop(PGA_T *pga);


#ifdef __cplusplus
}
#endif

#endif /* ____ */

