/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file adca.c
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "adca.h"
/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
*****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
*****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
*****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
*****************************************************************************/


/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/

/*****************************************************************************
 ** \brief	ADCA_ConfigRunMode
 **			ADCAģʽ
 ** \param [in] ConvertMode:(1)ADCA_CONVERT_SINGLE			
 **							(2)ADCA_CONVERT_CONTINUOUS
 **				ChannelSwitch: (1)ADCA_SWITCH_HARDWARE
 **							   (2)ADCA_SWITCH_SOFTWARE
 **				ClkDiv :(1)ADCA_CLK_DIV_1
 **						(2)ADCA_CLK_DIV_2
 **						(3)ADCA_CLK_DIV_4
 **						(4)ADCA_CLK_DIV_8
 **						(5)ADCA_CLK_DIV_16
 **						(6)ADCA_CLK_DIV_32
 **						(7)ADCA_CLK_DIV_64
 **						(8)ADCA_CLK_DIV_128
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_ConfigRunMode(uint32_t ConvertMode,uint32_t ChannelSwitch, uint32_t ClkDiv)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;
	ADCA->CON &= ~(ADCA_CON_ADCMS_Msk | ADCA_CON_ADCDIV_Msk | ADCA_CON_ADCSWCHE_Msk);
	ADCA->CON |= ConvertMode | ClkDiv | ChannelSwitch;
	ADCA->LOCK = 0x00;	
}
/*****************************************************************************
 ** \brief	ADCA_EnableChannel
 **			ADCAתͨ
 ** \param [in] ChannelMask: ADCA_CH_0_MSK ~ ADCA_CH_30_MSK
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_EnableChannel(uint32_t ChannelMask)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;		
	ADCA->SCAN |= ChannelMask;
	ADCA->LOCK = 0x00;	
}

/*****************************************************************************
 ** \brief	ADCA_AN30Select
 **			AN30ͨѡ
 ** \param [in] AN30Sel : (1)ADCA_AN30_SEL_BG
 **						  (2)ADCA_AN30_SEL_OP0O
 **						  (3)ADCA_AN30_SEL_OP1O
 **						  (4)ADCA_AN30_SEL_PGA0O
 **						  (5)ADCA_AN30_SEL_PGA1O
 **						  (6)ADCA_AN30_SEL_VSS
 **						  (7)ADCA_AN30_SEL_AVDD
 **						  (8)ADCA_AN30_SEL_AVSS
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_AN30Select(uint32_t AN30Sel)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;		
	ADCA->CON &= ~(ADCA_CON_ADCICHS_Msk);
	ADCA->CON |= (AN30Sel<< ADCA_CON_ADCICHS_Pos);	
	ADCA->LOCK = 0x00;		
}

/*****************************************************************************
 ** \brief	ADCA_DisableChannel
 **			رADCAתͨ
 ** \param [in] ChannelMask: ADCA_CH_0_MSK ~ ADCA_CH_30_MSK
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_DisableChannel(uint32_t ChannelMask)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;		
	ADCA->SCAN &= ~(ChannelMask);
	ADCA->LOCK = 0x00;	
}

/*****************************************************************************
 ** \brief	ADCA_ConfigSampleTime
 **			òʱ
 ** \param [in] SampleTime: ADCA_SAMPLE_8ADCA_SAMPLE_4
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_ConfigSampleTime(uint32_t SampleTime)
{

	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;		
	ADCA->CON &= ~(ADCA_CON_ADCSH_Msk);
	ADCA->CON |= (SampleTime<< ADCA_CON_ADCSH_Pos);
	ADCA->LOCK = 0x00;	
}

/*****************************************************************************
 ** \brief	ADCA_SelSoftwareSwitchChannel
 **			ѡлתͨ
 ** \param [in] Channel: ADCA_CH_0 ~ ADCA_CH_30
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_SelSoftwareSwitchChannel(uint32_t Channel)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;
	ADCA->CON2 = Channel;
	ADCA->LOCK = 0x00;	
}

/*****************************************************************************
 ** \brief	ADCA_GetResult
 **			ȡADCAת
 ** \param [in] Channel: ADCA_CH_0 ~ ADCA_CH_30
 ** \return  12 bits Value
 ** \note	
*****************************************************************************/
uint32_t ADCA_GetResult(uint32_t Channel)
{
	return(ADCA->DATA[Channel]);
}

/*****************************************************************************
 ** \brief	ADCA_EnableHardwareTrigger
 **			ӲADCAת
 ** \param [in] TriggerSource: (1)ADCA_TG_EXT_FALLING
 **							(2)ADCA_TG_EXT_RISING
 **							(3)ADCA_TG_INTNEL_ADCA
 **							(4)ADCA_TG_INTNEL_ADCB
 **							(5)ADCA_TG_INTNEL_TMR0
 **							(6)ADCA_TG_INTNEL_TMR1
 **							(7)ADCA_TG_INTNEL_TMR2
 **							(8)ADCA_TG_INTNEL_TMR3
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_EnableHardwareTrigger(uint32_t TriggerSource)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;
	switch(TriggerSource)
	{
		case ADCA_TG_EXT_FALLING:
		case ADCA_TG_EXT_RISING:
			ADCA->HWTG |= TriggerSource;
			break;
		case ADCA_TG_INTNEL_ADCA:
		case ADCA_TG_INTNEL_ADCB:
		case ADCA_TG_INTNEL_TMR0:
		case ADCA_TG_INTNEL_TMR1:
		case ADCA_TG_INTNEL_TMR2:
		case ADCA_TG_INTNEL_TMR3:			
			ADCA->HWTG &= ~(ADCA_HWTG_ADCINTTGSS_Msk);
			ADCA->HWTG |= TriggerSource;
			break;			
		default:
			break;
	}	
	ADCA->LOCK = 0x00;		
}
/*****************************************************************************
 ** \brief	ADCA_DisableHardwareTrigger
 **			رӲADCAת
 ** \param [in] TriggerSource: (1)ADCA_TG_EXT_FALLING
 **							(2)ADCA_TG_EXT_RISING
 **							(3)ADCA_TG_INTNEL_ADCA
 **							(4)ADCA_TG_INTNEL_ADC1
 **							(5)ADCA_TG_INTNEL_TMR0
 **							(6)ADCA_TG_INTNEL_TMR1
 **							(7)ADCA_TG_INTNEL_TMR2
 **							(8)ADCA_TG_INTNEL_TMR3
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_DisableHardwareTrigger(uint32_t TriggerSource)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;
	switch(TriggerSource)
	{
		case ADCA_TG_EXT_FALLING:
		case ADCA_TG_EXT_RISING:
			ADCA->HWTG &= ~(ADCA_HWTG_ADCEXTTEN_Msk);
			break;
		case ADCA_TG_INTNEL_ADCA:
		case ADCA_TG_INTNEL_ADCB:
		case ADCA_TG_INTNEL_TMR0:
		case ADCA_TG_INTNEL_TMR1:
		case ADCA_TG_INTNEL_TMR2:
		case ADCA_TG_INTNEL_TMR3:			
			ADCA->HWTG &= ~(ADCA_HWTG_ADCINTTGEN_Msk);
			break;			
		default:
			break;
	}	
	ADCA->LOCK = 0x00;		
}

/*****************************************************************************
 ** \brief	ADCA_EnableCompare
 **			ADCAȽϹ
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_EnableCompare(void)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;
	ADCA->CMP0 |= ADCA_CMP0_CMP0EN_Msk;
	ADCA->LOCK = 0x00;	
}
/*****************************************************************************
 ** \brief	ADCA_DisableCompare
 **			رADCAȽϹ
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_DisableCompare(void)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;
	ADCA->CMP0 &= ~(ADCA_CMP0_CMP0EN_Msk);
	ADCA->LOCK = 0x00;	
}
/*****************************************************************************
 ** \brief	ADCA_ConfigCompare
 **			ADCAȽϹ
 ** \param [in] CmpMode:(1)ADCA_CMP_LESS_THAN_RESULT
 **						(2)ADCA_CMP_NOT_LESS_THAN_RESULT
 **				 CmpCount: 0x00~0xf  ԤȽϴ
 **				 CmpChannel: ADCA_CH_0 ~ ADCA_CH_30
 **				 CmpData : 12 bit Ƚֵ
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_ConfigCompare(uint32_t CmpMode, uint32_t CmpCount,  
						uint32_t CmpChannel, uint32_t CmpData)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;
	ADCA->CMP0 &= ~(ADCA_CMP0_CMP0COND_Msk|ADCA_CMP0_CMP0MCNT_Msk|
					ADCA_CMP0_CMP0CHS_Msk| ADCA_CMP0_CMP0DATA_Msk);
	ADCA->CMP0 |= CmpMode | ((0xf & CmpCount)<<ADCA_CMP0_CMP0MCNT_Pos) | 
				((CmpChannel & 0x1f)<<ADCA_CMP0_CMP0CHS_Pos) | (0xfff &CmpData);
	ADCA->LOCK = 0x00;		
}

/*****************************************************************************
 ** \brief	ADCA_GetCompareResult
 **			ȡADCAȽ
 ** \param [in] none
 ** \return  1 /0
 ** \note	
*****************************************************************************/
uint32_t ADCA_GetCompareResult(void)
{
	return((ADCA->CMP0 & ADCA_CMP0_CMP0O_Msk)? 1:0);
}

/*****************************************************************************
 ** \brief	ADCA_EnableCompareInt
 **			ADCAȽж
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_EnableCompareInt(void)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;	
	ADCA->IMSC |= ADCA_IMSC_IMSC31_Msk;
	ADCA->LOCK = 0x00;	
}
/*****************************************************************************
 ** \brief	ADCA_DisableCompareInt
 **			رADCAȽж
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_DisableCompareInt(void)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;	
	ADCA->IMSC &= ~(ADCA_IMSC_IMSC31_Msk);
	ADCA->LOCK = 0x00;	
}
/*****************************************************************************
 ** \brief	ADCA_GetCompareIntFlag
 **			ȡADCAȽжʹܲҲжϱ־λ
 ** \param [in] none
 ** \return  1:жʹܲҲж 0ж
 ** \note	
*****************************************************************************/
uint32_t ADCA_GetCompareIntFlag(void)
{
	return((ADCA->MIS & ADCA_MIS_MIS31_Msk)? 1:0);
}
/*****************************************************************************
 ** \brief	ADCA_ClearCompareIntFlag
 **			ADCAȽжϱ־λ
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_ClearCompareIntFlag(void)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;	
	ADCA->ICLR |= (ADCA_ICLR_ICLR31_Msk);
	ADCA->LOCK = 0x00;	
}

/*****************************************************************************
 ** \brief	ADCA_EnableChannelInt
 **			ADCAͨnж
 ** \param [in] ChannelMask: ADCA_CH_0_MSK ~ ADCA_CH_30_MSK
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_EnableChannelInt(uint32_t ChannelMask)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;	
	ADCA->IMSC |= ChannelMask ;
	ADCA->LOCK = 0x00;	
}
/*****************************************************************************
 ** \brief	ADCA_DisableChannelInt
 **			رADCAͨnж
 ** \param [in] ChannelMask: ADCA_CH_0_MSK ~ ADCA_CH_30_MSK
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_DisableChannelInt(uint32_t ChannelMask)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;	
	ADCA->IMSC &= ~(ChannelMask);
	ADCA->LOCK = 0x00;
}
/*****************************************************************************
 ** \brief	ADCA_GetChannelIntFlag
 **			ȡADCAͨnжʹܲҲжϱ־λ
 ** \param [in] Channel:ADCA_CH_0 ~ ADCA_CH_30
 ** \return  1:жʹܲҲж 0ж
 ** \note	
*****************************************************************************/
uint32_t ADCA_GetChannelIntFlag(uint32_t Channel)
{
	return((ADCA->MIS & (0x1UL<<Channel))? 1:0);	
}
/*****************************************************************************
 ** \brief	ADCA_ClearChannelIntFlag
 **			ADCAͨnжϱ־λ
 ** \param [in] Channel:ADCA_CH_0 ~ ADCA_CH_30
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_ClearChannelIntFlag(uint32_t Channel)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;	
	ADCA->ICLR |= (0x01UL<< Channel);
	ADCA->LOCK = 0x00;		
}
/*****************************************************************************
 ** \brief	ADCA_Start
 **			ADCA
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_Start(void)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;	
	ADCA->CON |= ADCA_CON_ADCEN_Msk;
	ADCA->LOCK = 0x00;			
}
/*****************************************************************************
 ** \brief	ADCA_Stop
 **			رADCA
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void ADCA_Stop(void)
{
	ADCA->LOCK = ADCA_LOCK_WRITE_KEY;	
	ADCA->CON &= ~(ADCA_CON_ADCEN_Msk);
	ADCA->LOCK = 0x00;		
}

