/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file gpio.c
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "gpio.h"
/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
*****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
*****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
*****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
*****************************************************************************/


/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/

/*****************************************************************************
 ** \brief	 GPIO_ConfigRunMode
 **			 IOģʽ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 **				Mode:	 (1)GPIO_MODE_INPUT
 **						 (2)GPIO_MODE_OUTPUT
 **						 (3)GPIO_MODE_OPEN_DRAIN_WITHOUT_PULL_UP
 **						 (4)GPIO_MODE_OPEN_DRAIN_WITH_PULL_UP
 **						 (5)GPIO_MODE_INPUT_WITH_PULL_UP
 **						 (6)GPIO_MODE_INPUT_WITH_PULL_DOWN
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_ConfigRunMode(GPIO_T *port, uint32_t PinMask, uint32_t Mode)
{
	uint32_t Num;
	uint32_t Size =4;
	for(Num =0; Num <GPIO_PIN_NUM_MAX; Num++)
	{
		if(PinMask & (0x1 <<Num))
		{
			port->PMS &= ~(0x3 <<(Num*Size));
			port->PMS |= (Mode <<(Num*Size));
		}
	}
}
/*****************************************************************************
 ** \brief	 GPIO_EnableInt
 **			 IOж
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 **				Mode: (1)GPIO_INT_LEVEL_LOW
 **					  (2)GPIO_INT_LEVEL_HIGH
 **					  (3)GPIO_INT_EDGE_FALLING 
 **					  (4)GPIO_INT_EDGE_RISING
 **					  (5)GPIO_INT_EDGE_BOTH
 **					  (6)GPIO_WEKEUP_INT_EDGE_FALLING
 **					  (7)GPIO_WEKEUP_INT_EDGE_RISING
 **					  (8)GPIO_WEKEUP_INT_EDGE_BOTH
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_EnableInt(GPIO_T *port, uint32_t PinMask, uint32_t IntMode)
{
	switch(IntMode)
	{
		case GPIO_INT_LEVEL_LOW:
			port->ITYPE |= PinMask;
			port->IVAL  &= ~(PinMask);
			break;
		case GPIO_INT_LEVEL_HIGH:
			port->ITYPE |= PinMask;
			port->IVAL  |= PinMask;	
			break;
		case GPIO_INT_EDGE_FALLING:
			port->ITYPE &= ~(PinMask);
			port->IVAL  &= ~(PinMask);
			port->IANY  &= ~(PinMask);
			break;
		case GPIO_INT_EDGE_RISING:
			port->ITYPE &= ~(PinMask);
			port->IVAL  |= PinMask;
			port->IANY  &= ~(PinMask);
			break;
		case GPIO_INT_EDGE_BOTH:
			port->ITYPE &= ~(PinMask);
			port->IANY  |= PinMask;
			break;
	
		case GPIO_WEKEUP_INT_EDGE_FALLING:
			port->IVAL &= ~(PinMask);
			port->IANY  &= ~(PinMask);
			break;			
		case GPIO_WEKEUP_INT_EDGE_RISING:
			port->IVAL |= (PinMask);
			port->IANY  &= ~(PinMask);
			break;				
		case GPIO_WEKEUP_INT_EDGE_BOTH:
			port->IANY  |= PinMask;
			break;		
		default:
			break;
	}
	port->IMSC  |= PinMask;
}

/*****************************************************************************
 ** \brief	 GPIO_DisableInt
 **			 رIOж
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_DisableInt(GPIO_T *port, uint32_t PinMask)
{
	port->IMSC  &= ~(PinMask);
}

/*****************************************************************************
 ** \brief	 GPIO_GetIntFlag
 **			 ȡIOʹжϱ־λ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinNum: GPIO_PIN_0 ~ GPIO_PIN_7
 ** \return  0δж 1жʹܲж
 ** \note	
*****************************************************************************/
uint32_t GPIO_GetIntFlag(GPIO_T *port, uint32_t PinNum)
{
	return((port->MIS &(0x1<< PinNum))? 1:0);
}

/*****************************************************************************
 ** \brief	 GPIO_ClearIntFlag
 **			 IOжϱ־λ
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinNum: GPIO_PIN_0 ~ GPIO_PIN_7
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_ClearIntFlag(GPIO_T *port, uint32_t PinNum)
{
	port->ICLR |= (0x1<< PinNum);
}

/*****************************************************************************
 ** \brief	 GPIO_EnableFilter
 **			 IO˲
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 **				Fclk:	 (1)GPIO_FILCLK_1
 **						 (2)GPIO_FILCLK_2
 **						 (3)GPIO_FILCLK_3
 **						 (4)GPIO_FILCLK_5
 **						 (5)GPIO_FILCLK_9
 **						 (6)GPIO_FILCLK_17
 **						 (7)GPIO_FILCLK_33
 **						 (8)GPIO_FILCLK_65
 **						 (9)GPIO_FILCLK_129 
 **						 (10)GPIO_FILCLK_257 
 **						 (11)GPIO_FILCLK_513 
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_EnableFilter(GPIO_T *port, uint32_t PinMask, uint32_t Fclk)
{
	port->DIDB &= ~(GPIO_DIDB_DBCK_Msk);
	port->DIDB |=(PinMask | Fclk);	
}
/*****************************************************************************
 ** \brief	 GPIO_DisableFilter
 **			 رIO˲
 ** \param [in] port : GPIO0GPIO1 GPIO2GPIO3GPIO4
 **				PinMask: GPIO_PIN_0_MSK ~ GPIO_PIN_7_MSK
 ** \return  none
 ** \note	
*****************************************************************************/
void GPIO_DisableFilter(GPIO_T *port, uint32_t PinMask)
{
	port->DIDB &= ~(PinMask);
}
