/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file opa.c
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "opa.h"
/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
*****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
*****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
*****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
*****************************************************************************/


/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/

/*****************************************************************************
 ** \brief	 OPA_ConfigRunMode
 **			 ˷ģʽ
 ** \param [in] opa :OPA0 OPA1
 **				mode: (1)OPA_MS_OPA
 **					  (2)OPA_MS_CMP
 ** \return  none
 ** \note    
 *****************************************************************************/
void OPA_ConfigRunMode(OPA_T *opa, uint32_t mode)
{
	opa->CON0 &= ~(OPA_CON0_MS_Msk);
	opa->CON0 |= mode;		
}

/*****************************************************************************
 ** \brief	 OPA_ConfigPositive
 **			 ˷
 ** \param [in] opa :OPA0 OPA1
 **				PositiveSource:  (1)OPA_POSSEL_P	:OPnP
 **								 (2)OPA_POSSEL_BG 
 ** \return  none
 ** \note    
 *****************************************************************************/
void OPA_ConfigPositive(OPA_T *opa, uint32_t PositiveSource)
{
	opa->CON0 &= ~(OPA_CON0_PS_Msk);
	opa->CON0 |= PositiveSource;
}

/*****************************************************************************
 ** \brief	 OPA_ConfigNegative
 **			 ñȽ
 ** \param [in] opa :OPA0 OPA1
 **				NegativeSource:  (1)OPA_NEGSEL_N		:OPnN	
 **								 (2)OPA_NEGSEL_N1		:OPnN1	 
 ** \return  none
 ** \note   
 *****************************************************************************/
void OPA_ConfigNegative(OPA_T *opa, uint32_t NegativeSource)
{
	opa->CON0 &= ~(OPA_CON0_NS_Msk);
	opa->CON0 |= NegativeSource;
}

/*****************************************************************************
 ** \brief	 OPA_EnableOutput
 **			 ʹ˷
 ** \param [in] opa :OPA0 OPA1
 ** \return  none
 ** \note   
 *****************************************************************************/
void OPA_EnableOutput(OPA_T *opa)
{
	opa->CON0 |= OPA_CON0_OS_Msk;
}
/*****************************************************************************
 ** \brief	 OPA_DisableOutput
 **			 ر˷
 ** \param [in] opa :OPA0 OPA1
 ** \return  none
 ** \note   
 *****************************************************************************/
void OPA_DisableOutput(OPA_T *opa)
{
	opa->CON0 &= ~(OPA_CON0_OS_Msk);
}

/********************************************************************************
 ** \brief	 OPA_Start
 **			 OP
 ** \param [in] opa :OPA0 OPA1
 ** \return  none
 ** \note   
 ******************************************************************************/
void OPA_Start(OPA_T *opa)
{
	opa->CON0 |= OPA_CON0_EN_Msk;
}

/********************************************************************************
 ** \brief	 OPA_Stop
 **			 رOP
 ** \param [in] opa :OPA0 OPA1
 ** \return  none
 ** \note   
 ******************************************************************************/
void OPA_Stop(OPA_T *opa)
{
	opa->CON0 &= ~(OPA_CON0_EN_Msk);
}


