/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file system.c
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "system.h"
/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
*****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
*****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
*****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
*****************************************************************************/


/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/
/*****************************************************************************
 ** \brief	SYS_GetHSIState
 **			ȡHSI״̬
 ** \param [in] none			
 ** \return  0:ֹδȶ  1ȶ
 ** \note	
*****************************************************************************/
uint32_t  SYS_GetHSIState( void)
{
	return((SYS->CLKSTAT & SYS_CLKSTAT_IRCSTB_Msk)? 1:0);	
}

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/

/*****************************************************************************
 ** \brief	SYS_GetCPUResetFlag
 **			ȡCPUλ־
 ** \param [in] none			
 ** \return  0:δλ  1λ
 ** \note	
*****************************************************************************/
uint32_t  SYS_GetCPUResetFlag( void)
{
	return((SYS->RSTSTAT & SYS_RSTSTAT_CPURS_Msk)? 1:0);
}
/*****************************************************************************
 ** \brief	SYS_GetMCUResetFlag
 **			ȡMCUλ־
 ** \param [in] none			
 ** \return  0:δλ  1λ
 ** \note	
*****************************************************************************/
uint32_t  SYS_GetMCUResetFlag( void)
{
	return((SYS->RSTSTAT & SYS_RSTSTAT_MCURS_Msk)? 1:0);
}
/*****************************************************************************
 ** \brief	SYS_GetWDTResetFlag
 **			ȡWDTλϵͳ־
 ** \param [in] none			
 ** \return  0:WDTδλϵͳ  1WDTλϵͳ
 ** \note	
*****************************************************************************/
uint32_t  SYS_GetWDTResetFlag( void)
{
	return((SYS->RSTSTAT & SYS_RSTSTAT_WDTRS_Msk)? 1:0);
}
/*****************************************************************************
 ** \brief	WWDT_GetWWDTResetFlag
 **			ȡWWDTλϵͳ־
 ** \param [in] none			
 ** \return  0:WWDTδλϵͳ  1WWDTλϵͳ
 ** \note	
*****************************************************************************/
uint32_t  SYS_GetWWDTResetFlag( void)
{
	return((WWDT->CON & WWDT_WWDTCON_WWDTRF_Msk)? 1:0);	
}

/*****************************************************************************
 ** \brief	SYS_EnableClkOutput
 **			ʹϵͳʱ
 ** \param [in] none			
 ** \return  none
 ** \note	
*****************************************************************************/
void  SYS_EnableClkOutput(void)
{
	SYS->CLKODIV  |=SYS_CLKODIV_EN_Msk; 
}
/*****************************************************************************
 ** \brief	SYS_DisableClkOutput
 **			رϵͳʱ
 ** \param [in] none			
 ** \return  none
 ** \note	
*****************************************************************************/
void  SYS_DisableClkOutput(void)
{
	SYS->CLKODIV  &= ~(SYS_CLKODIV_EN_Msk); 	
}
/*****************************************************************************
 ** \brief	SYS_ConfigClkOutput
 **			ϵͳʱ
 ** \param [in] ClkSel : (1)SYS_CLK_OUT_SEL_AHB		
 **						 (2)SYS_CLK_OUT_SEL_HSI
 **				ClkDiv : 0~255   ʱƵ
 ** \return  none
 ** \note	0: FCLKO=FSEL 1~255: FCLKO=FSEL/(2DIV)
*****************************************************************************/
void  SYS_ConfigClkOutput(uint32_t ClkSel , uint32_t ClkDiv)
{
	SYS->CLKODIV  &= ~(SYS_CLKODIV_CLKSEL_Msk | SYS_CLKODIV_DIV_Msk ); 
	SYS->CLKODIV  |= ClkSel | ClkDiv;
}
/*****************************************************************************
 ** \brief	SYS_EnableHSI
 **			ʹܸʱ
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void  SYS_EnableHSI(void)
{
	uint32_t Temp;
	Temp = SYS->CLKCON;
	Temp |= SYS_CLKCON_IRCEN_Msk;
	SYS->CLKCON  =  SYS_CLKSEL_WRITE_KEY | (Temp & 0xffff);
}
/*****************************************************************************
 ** \brief	SYS_DisableHSI
 **			رոʱ
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void  SYS_DisableHSI(void)
{
	uint32_t Temp;
	Temp = SYS->CLKCON;
	Temp &= ~(SYS_CLKCON_IRCEN_Msk);
	SYS->CLKCON  =  SYS_CLKSEL_WRITE_KEY | (Temp & 0xffff);	
}
/*****************************************************************************
 ** \brief	SYS_ConfigHSI
 **			øʱ
 ** \param [in] HSISel: (1)SYS_CLK_HSI_64M
 **						(2)SYS_CLK_HSI_48M
 ** \return  none
 ** \note лͬHSI ƵʱҪԼ125us4~5*TLSIлѡƵʣ
 **		  ڴڼ䣬CPU ͣС
*****************************************************************************/
void  SYS_ConfigHSI(uint32_t HSISel)
{
	uint32_t Temp;
	Temp = SYS->CLKCON;
	Temp &= ~(SYS_CLKCON_IRCSEL_Msk);
	Temp |= HSISel;
	SYS->CLKCON  =  SYS_CLKSEL_WRITE_KEY | (Temp & 0xffff);		
}

/*****************************************************************************
 ** \brief	SYS_ConfigAHBClock
 **			AHBʱ
 ** \param [in] ClkSel :(1)SYS_CLK_SEL_HSI
 **						(2)SYS_CLK_SEL_LSI
 **				ClkDiv 0~ 255	
 ** \return  none
 ** \note	(1) 0: HCLK = FSYS  1~255: HCLK = FSYS/(2DIV)
*****************************************************************************/
void  SYS_ConfigAHBClock(uint32_t ClkSel, uint32_t ClkDiv)
{
	uint32_t  Delay = 10000;
	do{
		if(SYS_GetHSIState())
		{
			break;
		}
	}while(Delay--);
	
	SYS->CLKSEL = SYS_CLKSEL_WRITE_KEY | ClkSel;
	SYS->AHBCKDIV = ClkDiv;
}
/*****************************************************************************
 ** \brief	SYS_ConfigAPBClock
 **			APBʱ
 ** \param [in] ClkDiv 0~255				
 ** \return  none
 ** \note	(1) 0: PCLK = HCLK 1~255: PCLK = HCLK/(2DIV)
*****************************************************************************/
void  SYS_ConfigAPBClock( uint32_t ClkDiv)
{
	SYS->APBCKDIV = ClkDiv;
}

/*****************************************************************************
 ** \brief	SYS_EnableLVD
 **		 LVD 
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void SYS_EnableLVD(void)
{
	SYS->LVDCON |= SYS_LVDCON_LVDE_Msk;
}
/*****************************************************************************
 ** \brief	SYS_DisableLVD
 **		 رLVD 
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void SYS_DisableLVD(void)
{
	SYS->LVDCON &= ~(SYS_LVDCON_LVDE_Msk);
}

/*****************************************************************************
 ** \brief	SYS_ConfigLVDLevel
 **			LVDѹ
 ** \param [in] LVDLevel(1)SYS_LVD_2V		LVDѹѡ2V
 **						  (2)SYS_LVD_2P2V	LVDѹѡ2.2V
 **						  (3)SYS_LVD_2P4V	LVDѹѡ2.4V
 **						  (4)SYS_LVD_2P7V	LVDѹѡ2.7
 **						  (5)SYS_LVD_3V		LVDѹѡ3V
 **						  (6)SYS_LVD_3P7V	LVDѹѡ3.7	
 **						  (7)SYS_LVD_4P 	LVDѹѡ4.0	
 **						  (8)SYS_LVD_4P3V	LVDѹѡ4.3	
 ** \return  none
 ** \note	
*****************************************************************************/
void SYS_ConfigLVDLevel(uint32_t LVDLevel)
{
	SYS->LVDCON  &= ~(SYS_LVDCON_LVDS_Msk);
	SYS->LVDCON  |= LVDLevel;
}
/*****************************************************************************
 ** \brief	SYS_EnableLVDInt
 **			ʹLVDж
 ** \param [in] none			
 ** \return  none
 ** \note	
*****************************************************************************/
void SYS_EnableLVDInt(void)
{
	SYS->IMSC |= SYS_IMSC_LVDIMSC_Msk;
}
/*****************************************************************************
 ** \brief	SYS_DisableLVDInt
 **			رLVDж
 ** \param [in] none			
 ** \return  none
 ** \note	
*****************************************************************************/
void SYS_DisableLVDInt(void)
{
	SYS->IMSC &= ~(SYS_IMSC_LVDIMSC_Msk);
}
/*****************************************************************************
 ** \brief	SYS_GetLVDIntFlag
 **			ȡLVDж״̬־
 ** \param [in] none			
 ** \return  0δж 1ʹܲж
 ** \note	
*****************************************************************************/
uint32_t  SYS_GetLVDIntFlag(void)
{
	return((SYS->MIS & SYS_MIS_LVDMIS_Msk)? 1:0);
}
/*****************************************************************************
 ** \brief	SYS_ClearLVDIntFlag
 **			LVDж״̬־
 ** \param [in] none			
 ** \return  none
 ** \note	
*****************************************************************************/
void  SYS_ClearLVDIntFlag(void)
{
	SYS->ICLR |= SYS_ICLR_LVDICLR_Msk;
}
/*****************************************************************************
 ** \brief	SYS_GetLVDStateFlag
 **			ȡLVD״̬־
 ** \param [in] none			
 ** \return  1LVDVDD 0LVDСVDD
 ** \note	
*****************************************************************************/
uint32_t  SYS_GetLVDStateFlag(void)
{
	return ((SYS->LVDCON & SYS_LVDCON_LVDF_Msk)? 1:0);
}
/*****************************************************************************
 ** \brief	SYS_EnableSRAMProtect
 **			SRAM
 ** \param [in] SRAMAddrMask :(1) SYS_SRAM_PORTECT_2K_4K_MSK 	SRAM2K~4KַΧд
 **							  (2) SYS_SRAM_PORTECT_4K_6K_MSK	SRAM4K~6KַΧд
 **							  (3) SYS_SRAM_PORTECT_6K_8K_MSK	SRAM6K~8KַΧд
 ** \return  none
 ** \note	
*****************************************************************************/
void  SYS_EnableSRAMProtect(uint32_t SRAMAddrMask)
{
	uint32_t Temp;
	Temp = SYS->SRAMLOCK;
	Temp |= SRAMAddrMask;	
	SYS->SRAMLOCK = SYS_SRAMLOCK_WRITE_KEY | (Temp & 0xffff);
}
/*****************************************************************************
 ** \brief	SYS_DisableSRAMProtect
 **			رSRAM
 ** \param [in] SRAMAddrMask :(1) SYS_SRAM_PORTECT_2K_4K_MSK 	SRAM2K~4KַΧд
 **							  (2) SYS_SRAM_PORTECT_4K_6K_MSK	SRAM4K~6KַΧд
 **							  (3) SYS_SRAM_PORTECT_6K_8K_MSK	SRAM6K~8KַΧд
 ** \return  none
 ** \note	
*****************************************************************************/
void  SYS_DisableSRAMProtect(uint32_t SRAMAddrMask)
{
	uint32_t Temp;
	Temp = SYS->SRAMLOCK;
	Temp &= ~(SRAMAddrMask);	
	SYS->SRAMLOCK = SYS_SRAMLOCK_WRITE_KEY | (Temp & 0xffff);	
}
/*****************************************************************************
 ** \brief	SYS_DisablePeripheralClk
 **			رʱ
 ** \param [in] Module    :(1)SYS_CLK_ADCB_MSK	: 		 ADCBʱʹλ
 **						  (2)SYS_CLK_ACMP_MSK	:		ģȽʱʹλ				  
 **						  (3)SYS_CLK_OPA_PGA_MSK:	˷/PGAʱʹλ	
 **						  (4)SYS_CLK_EPWM_MSK:		EPWMʱʹλ	
 **						  (5)SYS_CLK_CRC_MSK:		CRCʱʹλ	
 **						  (6)SYS_CLK_WWDT_MSK:		WWDTʱʹλ	
 **						  (7)SYS_CLK_CCP_MSK:		/PWMʱʹλ	
 **						  (8)SYS_CLK_ADCA_MSK:		ADCAʱʹλ	
 **						  (9)SYS_CLK_SSP_MSK:		SSPʱʹλ	
 **						  (10)SYS_CLK_I2C_MSK:		I2Cʱʹλ	
 **						  (11)SYS_CLK_UART1_MSK:	UART1ʱʹλ	
 **						  (12)SYS_CLK_UART0_MSK:	UART0ʱʹλ	
 **						  (14)SYS_CLK_TIMER01_MSK:	ʱ01ʱʹλ	
 **						  (15)SYS_CLK_TIMER23_MSK:	ʱ23ʱʹλ											
 **						  (16)SYS_CLK_WDT_MSK:		WDTʱʹλ	
 ** \return  none
 ** \note	 
*****************************************************************************/	
void 	SYS_DisablePeripheralClk(uint32_t Module)
{
	SYS->APBCKEN &= ~(Module);	
}
/*****************************************************************************
 ** \brief	SYS_EnablePeripheralClk
 **			ʱ
 ** \param [in] Module    :(1)SYS_CLK_ADCB_MSK	: 		 ADCBʱʹλ
 **						  (2)SYS_CLK_ACMP_MSK	:		ģȽʱʹλ				  
 **						  (3)SYS_CLK_OPA_PGA_MSK:	˷/PGAʱʹλ	
 **						  (4)SYS_CLK_EPWM_MSK:		EPWMʱʹλ	
 **						  (5)SYS_CLK_CRC_MSK:		CRCʱʹλ	
 **						  (6)SYS_CLK_WWDT_MSK:		WWDTʱʹλ	
 **						  (7)SYS_CLK_CCP_MSK:		/PWMʱʹλ	
 **						  (8)SYS_CLK_ADCA_MSK:		ADCAʱʹλ	
 **						  (9)SYS_CLK_SSP_MSK:		SSPʱʹλ	
 **						  (10)SYS_CLK_I2C_MSK:		I2Cʱʹλ	
 **						  (11)SYS_CLK_UART1_MSK:	UART1ʱʹλ	
 **						  (12)SYS_CLK_UART0_MSK:	UART0ʱʹλ		
 **						  (14)SYS_CLK_TIMER01_MSK:	ʱ01ʱʹλ	
 **						  (15)SYS_CLK_TIMER23_MSK:	ʱ23ʱʹλ											
 **						  (16)SYS_CLK_WDT_MSK:		WDTʱʹλ	
 ** \return  none
 ** \note	 
*****************************************************************************/	
void 	SYS_EnablePeripheralClk(uint32_t Module)
{
	SYS->APBCKEN |= (Module);	
}

